### calculadora_jfmatta

#### Description.

The package calculadora_jfmatta is used for:

Simple calculations:

- Sum
- Subtraction
- Multiplication
- Division
- Potentiation
- Module.

#### Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install calculadora_jfmatta

```bash
pip install calculadora_jfmatta
```

#### Used

```python
from calculadora_jfmatta import calculadora
calculadora.calcular()

from calculadora_jfmatta import calculadora
calculadora.continuar_calculo()
```

#### Author

JulianoMata

#### License

[MIT](https://choosealicense.com/licenses/mit/)
